package com.sun.org.apache.xml.internal.serializer.dom3;

import java.io.IOException;
import org.xml.sax.SAXException;
import com.sun.org.apache.xml.internal.serializer.utils.WrappedRuntimeException;
import org.w3c.dom.Node;
import com.sun.org.apache.xml.internal.serializer.SerializationHandler;
import org.w3c.dom.ls.LSSerializerFilter;
import org.w3c.dom.DOMErrorHandler;
import com.sun.org.apache.xml.internal.serializer.DOM3Serializer;

public final class DOM3SerializerImpl implements DOM3Serializer
{
    private DOMErrorHandler fErrorHandler;
    private LSSerializerFilter fSerializerFilter;
    private String fNewLine;
    private SerializationHandler fSerializationHandler;
    
    public DOM3SerializerImpl(SerializationHandler handler) {
        this.fSerializationHandler = handler;
    }
    
    @Override
    public DOMErrorHandler getErrorHandler() {
        return this.fErrorHandler;
    }
    
    @Override
    public LSSerializerFilter getNodeFilter() {
        return this.fSerializerFilter;
    }
    
    @Override
    public void serializeDOM3(Node node) throws IOException {
        try {
            DOM3TreeWalker walker = new DOM3TreeWalker(this.fSerializationHandler, this.fErrorHandler, this.fSerializerFilter, this.fNewLine);
            walker.traverse(node);
        }
        catch (SAXException se) {
            throw new WrappedRuntimeException(se);
        }
    }
    
    @Override
    public void setErrorHandler(DOMErrorHandler handler) {
        this.fErrorHandler = handler;
    }
    
    @Override
    public void setNodeFilter(LSSerializerFilter filter) {
        this.fSerializerFilter = filter;
    }
    
    public void setSerializationHandler(SerializationHandler handler) {
        this.fSerializationHandler = handler;
    }
    
    @Override
    public void setNewLine(String newLine) {
        this.fNewLine = newLine;
    }
}
